/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.examples.mailreaderjpa;

/**
 * <p>Backing bean for the <code>/mainMenu.jsp</code> view.</p>
 */
public class MainMenu {


    // ------------------------------------------------------- Public Properties


    /**
     * <p>The per-user {@link State} instance we are associated with.  This
     * value will be injected, based on the managed bean configuration.</p>
     */
    private State state = null;


    /**
     * <p>Return the per-user {@link State} instance we are associated with.</p>
     */
    public State getState() {
        return this.state;
    }


    /**
     * <p>Set the per-user {@link State} instance we are associated with.</p>
     *
     * @param state The new State instance
     */
    public void setState(State state) {
        this.state = state;
    }


    // ------------------------------------------------------------- View Events


    /**
     * <p>Handle a request to edit the current user data.</p>
     */
    public String edit() {

        return "registration";

    }


    /**
     * <p>Handle a request to log off of the application.</p>
     */
    public String logoff() {

        getState().setUser(null);
        return "welcome";

    }


}
