/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.examples.mailreaderjpa;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.ConverterException;
import org.apache.mailreaderjpa.Protocol;

/**
 * <p>JSF <code>Converter</code> for mapping between a <code>Protocol</code>
 * and its string representation.</p>
 */
public class ProtocolConverter implements Converter {
    

    // ------------------------------------------------------- Converter Methods


    /**
     * <p>Return the string representation of the specified
     * <code>Protocol</code> value.</p>
     *
     * @param context <code>FacesContext</code> for the current request
     * @param component <code>UIComponent</code> whose value is being converted
     * @param value {@link Protocol} being converted
     *
     * @exception ConverterException if a conversion error occurs
     */
    public String getAsString(FacesContext context, UIComponent component,
            Object value) throws ConverterException {

        Protocol protocol = (Protocol) value;
        return "" + protocol.getId();

    }


    /**
     * <p>Return the <code>Protocol</code> instance corresponding to the
     * specified string representation.</p>
     *
     * @param context <code>FacesContext</code> for the current request
     * @param component <code>UIComponent</code> whose value is being converted
     * @param value String representation of the value
     *
     * @exception ConverterException if a conversion error occurs
     */
    public Object getAsObject(FacesContext context, UIComponent component,
            String value) throws ConverterException {

        Logic logic = 
          (Logic) context.getExternalContext().getApplicationMap().get("logic");
        return logic.findProtocolById(Integer.valueOf(value).intValue());

    }


}
